@@ -24,3 +24,6 @@ LOGGING_TB_LIMIT = getattr(settings, "CSU_LOGGING_TB_LIMIT", 5)
 LOGGING_REQUEST_BODY_LIMIT = getattr(settings, "CSU_LOGGING_REQUEST_BODY_LIMIT", 102400)
 LOGGING_RESPONSE_BODY_LIMIT = getattr(settings, "CSU_LOGGING_RESPONSE_BODY_LIMIT", 102400)
 LOGGING_SHOW_HEADERS = getattr(settings, "CSU_LOGGING_SHOW_HEADERS", False)
+
+SERVICE_REQUEST_CONTENT_LOG_LIMIT = getattr(settings, "CSU_SERVICE_REQUEST_CONTENT_LOG_LIMIT", None)
+SERVICE_RESPONSE_CONTENT_LOG_LIMIT = getattr(settings, "CSU_SERVICE_RESPONSE_CONTENT_LOG_LIMIT", 10240)
