@@ -1,15 +1,18 @@
+from typing import TYPE_CHECKING
 from typing import NotRequired
 from typing import Protocol
 from typing import TypedDict
 from typing import Unpack
 
 from rest_framework.permissions import BasePermission
-from rest_framework.request import Request
-from rest_framework.views import APIView
+
+if TYPE_CHECKING:
+    from rest_framework.request import Request
+    from rest_framework.views import APIView
 
 
 class PermissionTest(Protocol):
-    def __call__(self, request: Request, view: APIView) -> bool: ...
+    def __call__(self, request: "Request", view: "APIView") -> bool: ...
 
 
 class MethodTests(TypedDict):
