@@ -1,6 +1,8 @@
 import builtins
 import os
 import pathlib
+import re
+from datetime import timedelta
 
 UNSET = object()
 
@@ -61,3 +63,39 @@ def path(key, default=UNSET) -> pathlib.Path | None:
         value = pathlib.Path(value)
         assert value.exists(), f"{value!r} does not exist"
         return value
+
+
+DURATION_RE = re.compile(
+    r"""
+        ^P
+        (?:(?P<days>\d+\.\d+|\d+)D)?
+        T?
+        (?:(?P<hours>\d+\.\d+|\d+)H)?
+        (?:(?P<minutes>\d+\.\d+|\d+)M)?
+        (?:(?P<seconds>\d+\.\d+|\d+)S)?
+        $
+    """,
+    re.VERBOSE,
+)
+
+
+def duration(
+    key,
+    default=UNSET,
+) -> timedelta | None:
+    """
+    Parses a ISO8601-ish duration.
+    """
+    value = str(key, default)
+    if value is None:
+        return
+    else:
+        match = DURATION_RE.match(value)
+        if not match:
+            raise ValueError(f"Invalid ISO 8601 duration: {value!r} did not match.")
+        print(match.groupdict())
+        parts = {k: builtins.float(v) for k, v in match.groupdict("0").items()}
+        try:
+            return timedelta(**parts)
+        except Exception as exc:
+            raise ValueError(f"Invalid ISO 8601 duration: {value!r} raised: {exc!r}") from exc
